(function (React, ReactDOM, d3) {
    'use strict';
  
    var React__default = 'default' in React ? React['default'] : React;
    ReactDOM = ReactDOM && Object.prototype.hasOwnProperty.call(ReactDOM, 'default') ? ReactDOM['default'] : ReactDOM;
  
    const csvUrl =
      'https://gist.githubusercontent.com/eravellisaimeghana/6d535ddc33f32f5d5b00d5e8f39d08c0/raw/b5b5d3d65463da939143afb6ff02a5cd064e7860/top%252010%2520car%2520prices.csv';
    const width = 920;
    const height = 545;
    const margin = { top: 15, right: 15, bottom: 52, left: 300 };
  
  
  
    const App = () => {
      const [data, setData] = React.useState(null);
  
      React.useEffect(() => {
        const row = d => {
          d.Gross = +d['Price'];
          return d;
        };
        d3.csv(csvUrl, row).then(data => {
          setData(data.slice(0, 10));
        });
      }, []);
  
      if (!data) {
        return React__default.createElement( 'pre', null, "Loading..." );
      }
  
      const innerHeight = height - margin.top - margin.bottom - 140;
      const innerWidth = width - margin.left - margin.right;
  
      const yScale = d3.scaleBand()
        .domain(data.map(d => d.Car))
        .range([0, innerHeight]);
  
      const xScale = d3.scaleLinear()
        .domain([0, d3.max(data, d => d.Gross)])
        .range([0, innerWidth]);
  
      return (
        React__default.createElement( 'svg', { width: width, height: height },
          React__default.createElement( 'g', { transform: `translate(${margin.left},${margin.top})` },
            xScale.ticks().map(tickValue => (
              React__default.createElement( 'g', { key: tickValue, transform: `translate(${xScale(tickValue)},0)` },
                React__default.createElement( 'line', { y2: innerHeight, stroke: "orange" }),
                React__default.createElement( 'text', {
                  style: { textAnchor: 'middle' }, dy: ".70em", y: innerHeight + 3 },
                  tickValue
                )
              )
            )),
            yScale.domain().map(tickValue => (
              React__default.createElement( 'text', {
                key: tickValue, style: { textAnchor: 'end' }, x: -3, dy: ".32em", y: yScale(tickValue) + yScale.bandwidth() / 2 },
                tickValue
              )
            )),
            data.map(d => (
              React__default.createElement( 'rect', {
                key: d.Car, x: 0, y: yScale(d.Car), width: xScale(d.Gross), height: yScale.bandwidth() })
            ))
          )
        )
      );
    };
    const rootElement = document.getElementById('root');
    ReactDOM.render(React__default.createElement( App, null ), rootElement);
  
  }(React, ReactDOM, d3));

  